@@ -1,6 +1,4 @@
-#' Download data.frame with a summary of the data sets included in grobr
-#'
-#' Download data.frame with a summary of the data sets included in grobr
+#' Support function to download metadata internally used in geobr
 #'
 #' @export
 #' @family general support functions
@@ -14,18 +12,17 @@
 #'
 download_metadata <- function(){
 
-
   # Get metadata with data addresses
-  tempf <- file.path(tempdir(), "metadata.rds")
+  tempf <- file.path(tempdir(), "metadata.csv")
 
   # check if metadata has already been downloaded
   if (file.exists(tempf)) {
-    metadata <- readr::read_rds(tempf)
+    metadata <- utils::read.csv(tempf, stringsAsFactors=F)
 
   } else {
     # download it and save to metadata
-    httr::GET(url="http://www.ipea.gov.br/geobr/metadata/metadata.rds", httr::write_disk(tempf, overwrite = T))
-    metadata <- readr::read_rds(tempf)
+    httr::GET(url="http://www.ipea.gov.br/geobr/metadata/metadata_gpkg.csv", httr::write_disk(tempf, overwrite = T))
+    metadata <- utils::read.csv(tempf, stringsAsFactors=F)
   }
 
   return(metadata)
