@@ -5,6 +5,8 @@
 #' data comes from MMA and can be found at http://mapas.mma.gov.br/i3geo/datadownload.htm .
 #'
 #' @param date A date number in YYYYMM format
+#' @param tp Whether the function returns the 'original' dataset with high resolution or a dataset with 'simplified' borders (Default)
+#'
 #' @export
 #' @family general area functions
 #' @examples \donttest{
@@ -14,16 +16,16 @@
 #' # Read conservation_units
 #'   b <- read_conservation_units(date=201909)
 #'}
-#'
-read_conservation_units <- function(date=NULL){
+read_conservation_units <- function(date=NULL, tp="simplified"){
 
   # Get metadata with data addresses
   metadata <- download_metadata()
 
-
   # Select geo
   temp_meta <- subset(metadata, geo=="conservation_units")
 
+  # Select data type
+  temp_meta <- select_data_type(temp_meta, tp)
 
   # 1.1 Verify year input
   if (is.null(date)){ date <- 201909
@@ -34,10 +36,6 @@ read_conservation_units <- function(date=NULL){
                                                paste(unique(temp_meta$year),collapse = " ")))
   }
 
-
-
-
-
   # # Select metadata year
   # x <- year
   # temp_meta <- subset(temp_meta, year==x)
@@ -46,10 +44,9 @@ read_conservation_units <- function(date=NULL){
   filesD <- as.character(temp_meta$download_path)
 
   # download files
-  temps <- paste0(tempdir(),"/", unlist(lapply(strsplit(filesD,"/"),tail,n=1L)))
-  httr::GET(url=filesD, httr::progress(), httr::write_disk(temps, overwrite = T))
+  temps <- download_gpkg(filesD)
 
   # read sf
-  temp_sf <- readr::read_rds(temps)
+  temp_sf <- sf::st_read(temps, quiet=T)
   return(temp_sf)
 }
