@@ -1,6 +1,8 @@
 #' Download shape file of Brazil as sf objects. Data at scale 1:250,000, using Geodetic reference system "SIRGAS2000" and CRS(4674)
 #'
 #' @param year Year of the data (defaults to 2010)
+#' @param tp Whether the function returns the 'original' dataset with high resolution or a dataset with 'simplified' borders (Default)
+#'
 #' @export
 #' @family general area functions
 #' @examples \donttest{
@@ -12,36 +14,37 @@
 #'
 #'}
 
-read_country <- function(year=NULL){
+read_country <- function(year=NULL, tp="simplified"){
 
   # Get metadata with data addresses
   metadata <- download_metadata()
 
-
   # Select geo
-  temp_ano <- subset(metadata, geo=="country")
+  temp_meta <- subset(metadata, geo=="country")
+
+  # Select data type
+  temp_meta <- select_data_type(temp_meta, tp)
 
 
   # Verify year input
   if (is.null(year)){ message("Using data from year 2010\n")
-    temp_ano <- subset(temp_ano, year==2010)
+    temp_meta <- subset(temp_meta, year==2010)
 
-  } else if (year %in% temp_ano$year){ temp_ano <- temp_ano[temp_ano[,2] == year, ]
+  } else if (year %in% temp_meta$year){ temp_meta <- temp_meta[temp_meta[,2] == year, ]
 
   } else { stop(paste0("Error: Invalid Value to argument 'year'. It must be one of the following: ",
-                       paste(unique(temp_ano$year),collapse = " ")))
+                       paste(unique(temp_meta$year),collapse = " ")))
   }
 
 
   # list paths of files to download
-  filesD <- as.character(temp_ano$download_path)
+  filesD <- as.character(temp_meta$download_path)
 
   # download files
-  temps <- paste0(tempdir(),"/", unlist(lapply(strsplit(filesD,"/"),tail,n=1L)))
-  httr::GET(url=filesD, httr::progress(), httr::write_disk(temps, overwrite = T))
+  temps <- download_gpkg(filesD)
 
   # read sf
-  temp_sf <- readr::read_rds(temps)
+  temp_sf <- sf::st_read(temps, quiet=T)
 
   return(temp_sf)
 }
