@@ -29,21 +29,17 @@ read_health_facilities <- function(){
   # Get metadata with data addresses
   metadata <- download_metadata()
 
-
   # Select geo
   temp_meta <- subset(metadata, geo=="health_facilities")
 
-
   # list paths of files to download
     filesD <- as.character(temp_meta$download_path)
 
-    # download files
-    temps <- paste0(tempdir(),"/", unlist(lapply(strsplit(filesD,"/"),tail,n=1L)))
-    httr::GET(url=filesD, httr::progress(), httr::write_disk(temps, overwrite = T))
-
+  # download files
+    temps <- download_gpkg(filesD)
 
   # read sf
-    temp_sf <- readr::read_rds(temps)
+    temp_sf <- sf::st_read(temps, quiet=T)
     return(temp_sf)
 
     }
