@@ -5,6 +5,7 @@
 #' @param year Year of the data (defaults to 2010)
 #' @param code_meso The 4-digit code of a meso region. If the two-digit code or a two-letter uppercase abbreviation of
 #'  a state is passed, (e.g. 33 or "RJ") the function will load all meso regions of that state. If code_meso="all", all meso regions of the country are loaded.
+#' @param tp Whether the function returns the 'original' dataset with high resolution or a dataset with 'simplified' borders (Default)
 #' @export
 #' @family general area functions
 #' @examples \donttest{
@@ -24,7 +25,7 @@
 #' }
 #'
 
-read_meso_region <- function(code_meso, year=NULL){
+read_meso_region <- function(code_meso="all", year=NULL, tp="simplified"){
 
 
   # Get metadata with data addresses
@@ -32,8 +33,10 @@ read_meso_region <- function(code_meso, year=NULL){
 
 
   # Select geo
-  temp_meta <- subset(metadata, geo=="meso_regiao")
+  temp_meta <- subset(metadata, geo=="meso_region")
 
+  # Select data type
+  temp_meta <- select_data_type(temp_meta, tp)
 
   # Verify year input
   if (is.null(year)){ message("Using data from year 2010\n")
@@ -46,10 +49,7 @@ read_meso_region <- function(code_meso, year=NULL){
   }
 
 
-  # Verify code_meso input
-
-  # Test if code_meso input is null
-  if(is.null(code_meso)){ stop("Value to argument 'code_meso' cannot be NULL") }
+# Verify code_meso input
 
   # if code_meso=="all", read the entire country
   if(code_meso=="all"){ message("Loading data for the whole country\n")
@@ -63,9 +63,9 @@ read_meso_region <- function(code_meso, year=NULL){
 
     # download files
       lapply(X=filesD, function(x){
-                                    i <- match(c(x),filesD);
+                                    i <- match(c(x),filesD)
                                     httr::GET(url=x, #httr::progress(),
-                                            httr::write_disk(paste0(tempdir(),"/", unlist(lapply(strsplit(x,"/"),tail,n=1L))), overwrite = T));
+                                            httr::write_disk(paste0(tempdir(),"/", unlist(lapply(strsplit(x,"/"),tail,n=1L))), overwrite = T))
                                     utils::setTxtProgressBar(pb, i)
                                   }
              )
@@ -75,7 +75,7 @@ read_meso_region <- function(code_meso, year=NULL){
     # read files and pile them up
     files <- unlist(lapply(strsplit(filesD,"/"), tail, n = 1L))
     files <- paste0(tempdir(),"/",files)
-    files <- lapply(X=files, FUN= readr::read_rds)
+    files <- lapply(X=files, FUN= sf::st_read, quiet=T)
     shape <- do.call('rbind', files)
     return(shape)
   }
@@ -92,11 +92,10 @@ read_meso_region <- function(code_meso, year=NULL){
 
 
     # download files
-    temps <- paste0(tempdir(),"/", unlist(lapply(strsplit(filesD,"/"),tail,n=1L)))
-    httr::GET(url=filesD, httr::write_disk(temps, overwrite = T))
+    temps <- download_gpkg(filesD)
 
     # read sf
-    shape <- readr::read_rds(temps)
+    shape <- sf::st_read(temps, quiet=T)
 
     if(nchar(code_meso)==2){
       return(shape)
