@@ -1,14 +1,15 @@
-context("Read")
+context("read_conservation_units")
+
+# skip tests because they take too much time
+testthat::skip_on_cran()
+# testthat::skip_on_travis()
+# skip_if(Sys.getenv("TEST_ONE") != "")
 
 
 # Reading the data -----------------------
 
 test_that("read_conservation_units", {
 
-  # skip tests because they take too much time
-  skip_on_cran()
-  skip_on_travis()
-
   # read data
   test_sf <- read_conservation_units(date=201909)
   expect_output(read_conservation_units(date=NULL))
@@ -28,10 +29,6 @@ test_that("read_conservation_units", {
 # ERRORS and messagens  -----------------------
 test_that("read_conservation_units", {
 
-  # skip tests because they take too much time
-  skip_on_cran()
-  skip_on_travis()
-
   # Wrong date
   expect_error(read_conservation_units(date=9999999))
   expect_error(read_conservation_units(date="xxx"))
