@@ -1,19 +1,16 @@
-context("Read")
+context("read_country")
 
+testthat::skip_on_cran()
+# testthat::skip_on_travis()
+# skip_if(Sys.getenv("TEST_ONE") != "")
 
 # Reading the data -----------------------
 
 test_that("read_country", {
 
-  # skip tests because they take too much time
-  skip_on_cran()
-  skip_on_travis()
-
-
   # read data
   test_sf <- read_country(year=1991)
 
-
   # check sf object
   expect_true(is(test_sf, "sf"))
 
@@ -30,10 +27,6 @@ test_that("read_country", {
 # ERRORS and messagens  -----------------------
 test_that("read_country", {
 
-  # skip tests because they take too much time
-  skip_on_cran()
-  skip_on_travis()
-
   # Wrong date
   expect_error(read_country(year=9999999))
   expect_error(read_country(year="xxx"))
