@@ -1,4 +1,9 @@
-context("Read")
+context("read_disaster_risk_area")
+
+# skip tests because they take too much time
+testthat::skip_on_cran()
+# testthat::skip_on_travis()
+# skip_if(Sys.getenv("TEST_ONE") != "")
 
 
 
@@ -7,16 +12,11 @@ context("Read")
 
 test_that("read_disaster_risk_area", {
 
-  # skip tests because they take too much time
-  skip_on_cran()
-  skip_on_travis()
-
   # read data
   test_sf <- read_disaster_risk_area(year=2010)
     # test
     expect_equal(test_sf %>% length(), 10)
 
-
 }
 )
 
@@ -28,9 +28,6 @@ test_that("read_disaster_risk_area", {
 
 test_that("read_disaster_risk_area", {
 
-  # skip tests because they take too much time
-  skip_on_cran()
-  skip_on_travis()
 
   # read data
   test_sf <- read_disaster_risk_area(year=2010)
@@ -42,7 +39,7 @@ test_that("read_disaster_risk_area", {
   expect_equal(test_sf$geo_bater %>% length(), 8309)
 
   # check projection
-  expect_equal(sf::st_crs(test_sf)[[2]], "+proj=longlat +ellps=GRS80 +no_defs")
+  expect_equal(sf::st_crs(test_sf)[[2]], "+proj=longlat +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +no_defs")
 
 })
 
@@ -52,10 +49,6 @@ test_that("read_disaster_risk_area", {
 # ERRORS and messagens  -----------------------
 test_that("read_disaster_risk_area", {
 
-  # skip tests because they take too much time
-  skip_on_cran()
-  skip_on_travis()
-
   # Wrong year
   expect_error(read_disaster_risk_area(year=9999999))
   expect_error(read_disaster_risk_area(year="xxx"))
