@@ -1,14 +1,14 @@
-context("Read")
+context("read_indigenous_land")
 
+# skip tests because they take too much time
+testthat::skip_on_cran()
+# testthat::skip_on_travis()
+# skip_if(Sys.getenv("TEST_ONE") != "")
 
 # Reading the data -----------------------
 
 test_that("read_indigenous_land", {
 
-  # skip tests because they take too much time
-  skip_on_cran()
-  skip_on_travis()
-
   # read data
   test_sf <- read_indigenous_land(date=201907)
 
@@ -19,7 +19,7 @@ test_that("read_indigenous_land", {
   expect_equal(test_sf$code_terrai %>% length(), 615)
 
   # check projection
-#  expect_equal(sf::st_crs(test_sf)[[2]], "+proj=longlat +ellps=GRS80 +no_defs")
+  expect_equal(sf::st_crs(test_sf)[[2]], "+proj=longlat +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +no_defs")
 
 })
 
@@ -28,10 +28,6 @@ test_that("read_indigenous_land", {
 # ERRORS and messagens  -----------------------
 test_that("read_indigenous_land", {
 
-  # skip tests because they take too much time
-  skip_on_cran()
-  skip_on_travis()
-
   # Wrong date
   expect_error(read_indigenous_land(date=9999999))
   expect_error(read_indigenous_land(date="xxx"))
