@@ -1,14 +1,14 @@
-context("Read")
+context("read_intermediate_region")
 
+# skip tests because they take too much time
+testthat::skip_on_cran()
+# testthat::skip_on_travis()
+# skip_if(Sys.getenv("TEST_ONE") != "")
 
 # Reading the data -----------------------
 
 test_that("read_intermediate_region", {
 
-  # skip tests because they take too much time
-  skip_on_cran()
-  skip_on_travis()
-
   # read data
   expect_message(read_intermediate_region(year=NULL))
   test_sf <- read_intermediate_region(year=2017)
@@ -38,11 +38,6 @@ test_that("read_intermediate_region", {
 # ERRORS and messagens  -----------------------
 test_that("read_intermediate_region", {
 
-  # skip tests because they take too much time
-  skip_on_cran()
-  skip_on_travis()
-
-
   # Wrong year
   expect_error(read_intermediate_region(year = 9999999))
   expect_error(read_intermediate_region(year = "xxx"))
